#
# spec file for package python-kazoo
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-kazoo
Version:        2.10.0
Release:        2.1
Summary:        Higher Level Zookeeper Client
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/python-zk/kazoo
Source:         https://files.pythonhosted.org/packages/source/k/kazoo/kazoo-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-six
Suggests:       python-pure-sasl
BuildArch:      noarch
%ifpython2
Requires:       python-eventlet >= 0.17.1
Requires:       python-gevent >= 1.2
%endif
%python_subpackages

%description
Implements a higher level API to Apache Zookeeper for Python clients.

%prep
%setup -q -n kazoo-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# kazoo needs running zookeeper server

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/kazoo
%{python_sitelib}/kazoo-%{version}*-info

%changelog
* Wed Nov 20 2024 Matej Cepl <mcepl@cepl.eu>
- Clean up the SPEC file.
* Fri Nov  1 2024 Fergal Mc Carthy <fmccarthy@suse.com>
- Add sle15_python_module_pythons macro
* Sun Feb  4 2024 Dirk Müller <dmueller@suse.com>
- update to 2.10.0:
  * update tested ZK versions
  * remove Python 3.7, add Python 3.11 and Python 3.12
  * bump pypy to latest available
  * add SSL test
  * no need to specify `mock`
  * remove unecessary import guard for gevent.lock
  * remove string interpolation in favour of exception chaining
  * remove backport of 'atexit.unregister'
  * Replace usage of six for their py3 implementations
  * **core:**  no need to alway perform an `os.stat(fd)`
  * **exceptions:**  Register exception for server-side
    QUOTAEXCEEDED(-125)
* Fri Oct 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2.9.0
  Chore
  * migrate to setup.cfg (#666) (5f7ae483)
  * ci:
    testing with Python3.10 and ZK 3.5.10, 3.6.3, 3.7.1 (#659) (bd627973)
    better specify how to trigger Github Actions (#658) (1ea097d5)
    Replace Travis with Github Actions (8eb462f2)
  * Doc
    fix simple typo, untill -> until (85f1b5fc)
  * Features
    core: make DNS resolution error retriable (#631) (e0810242)
  * Bug Fixes
    core:
    use selectors to poll connections instead of raw select in threading,gevent,eventlet (#656) (4042a850)
    do not allow responses to choke request and ping processing (89e06603)
  * recipe:
    fix deadlock in r/w lock recipe (#650) (9bb84994, closes #649)
    fix deprecation warning from threading.Event (569c89cd)
* Tue May 17 2022 pgajdos@suse.com
- drop test dependencies from BuildRequires, we do not plan to
  run the testsuite
* Thu Sep 16 2021 Steve Kowalik <steven.kowalik@suse.com>
- Actually remove nose BuildRequires, replacing it with pytest.
* Tue Sep 15 2020 pgajdos@suse.com
- does not require nose for testing (even upstream uses pytest)
* Fri Jul 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 2.8.0:
  * **chore:**  using Github templates for issues and PRs (#610) ([eddc0976](https://github.com/python-zk/kazoo/commit/eddc0976bf1ef9d9fb97990cebbc3f9b1abe9d7d))
  * **core:**
  * Use strict regex to identify lock contenders. ([cc8ce892](https://github.com/python-zk/kazoo/commit/cc8ce8929116a1f0a2f0d088afa82ac9576395dc))
  * Support additionaal lock contenter patterns ([225eeecb](https://github.com/python-zk/kazoo/commit/225eeecbe66c10d46dc7928681783d17f389f13a))
  * **tests:**
  * Disable problematic hound-flake8-black integration. ([75f62a0d](https://github.com/python-zk/kazoo/commit/75f62a0dd40a9f9bdefcb04cea5ee5fcd3438c0e))
  * Move to pytest ([de97d74b](https://github.com/python-zk/kazoo/commit/de97d74b50b62cd2f0cddc2a04e150575d9c6bc7))
  * add Python 3.8 and remove Python 3.6 from the testing suite (#611) ([e4f808f7](https://github.com/python-zk/kazoo/commit/e4f808f7f0fe17e7e01468a2c54684f048e12b52))
  * **core:**  Use chain.from_iterable in threading.py (#614) ([13c73ec5](https://github.com/python-zk/kazoo/commit/13c73ec5f4d4f2215deb987a059051bb821674ca))
  * **core:**
  * handle SSL_WANT_READ/WRITE errors (#619) ([cbdc4749](https://github.com/python-zk/kazoo/commit/cbdc4749edb5879099c1f9b832c055d9eeb52dea), closes [#618](https://github.com/python-zk/kazoo/issues/618))
  * '"is" with a literal' syntax errors (#609) ([6b6ffe62](https://github.com/python-zk/kazoo/commit/6b6ffe62a073d1ed5413c65c2d8ec94ea2fa1760))
  * sync() return should be unchrooted ([cbde70ac](https://github.com/python-zk/kazoo/commit/cbde70ac87435afbbacc9806c675184c7f778343), closes [#601](https://github.com/python-zk/kazoo/issues/601))
  * **core:**  Update matrix: add pypy3, drop py27 ([522189da](https://github.com/python-zk/kazoo/commit/522189da0f238faafc8f1db34f682f49b15ec503))
  * **tests:**  Add coverage report on codecov.io ([bb475843](https://github.com/python-zk/kazoo/commit/bb475843905af1a2d25b1f5834085c85c28bb175))
* Mon Mar 30 2020 Dirk Mueller <dmueller@suse.com>
- downgrade pure-sasl dependency to suggests, as it requires
  kerberos which conflicts with pykerberos (needed by requests)
  and the code handles this as optional dependency
* Mon Mar 16 2020 Dirk Mueller <dmueller@suse.com>
- add dependency on pure-sasl, move python 2.x deps inside a conditional
* Mon Mar 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 2.7.0:
  * *core:**
  * run SASL Kerberos tests as part of build
  * Add create2 support
  * closed states instead of lost states (#573)
  * *recipe:**  add support for curator SharedCount recipe (#559)
  * *core:**
  * allow requests to be queued in CONNECTING state (#374) (#588)
  * when connection fails, close the ConnectionHandler (#577) (#579)
  * *tests:**
  * Disable JAAS isInitiator for Server
  * deactivate TCP port that was enabled by default.
  * capitalize the default_domain value
  * prefix with toxinidir variable with a / to ensure path to ensure-zookeeper-env.sh is correct
  * specify -Dfile.encoding=UTF-8 when starting the ZK JVM
* Mon Apr  8 2019 pgajdos@suse.com
- version update to 2.5.1
  * *client:**  add missing paren (#550)
  * *core:** support deprecated KazooRetry argument (#545)
  * *core:** reduce timeout for the first Connect() request (#540)
  * *handlers:**  make AsyncResult call all registered callbacks
    instantly if the handler has stopped running (#549)
  * *recipe:** No more memory leak when ChildrenWatch was stopped (#543)
  * *recipe:** No more memory leak once TreeCache was closed (#524)
* Thu Nov  1 2018 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.5.0:
  * Various fixes for gevent and python 3.7
- Fix homepage
* Tue Aug 22 2017 tbechtold@suse.com
- update to 2.4.0:
  * add missed parens to LockingQueue function call.
  * revert PR #305 SetWatches which caused RuntimeError
  * pep8 all the things
  * drop Python 2.6/3.3 official support, add 3.5/3.6 testing
  * allow multiple endpoints in KazooClient hosts arg
  * use epoll when available to support fds > 1023
  * Add TreeCache recipe
  * update MANIFEST.in to reflect changes to filenames
  * add travis deployment and update ZK versions
  * allow having observers and different sized clusters
  * fully resolve multiple records for hosts in the zookeeper
    connection string
  * Fix the recipe examples, so they actually work by connecting to
    ZooKeeper. Without start() they just hang and can't be killed.
* Thu Sep 29 2016 dmueller@suse.com
- update to 2.2.1:
  * Issue #234: Add support for reconfig cluster membership operation
  * Start running tests against Zookeeper 3.5.0 alpha and explicitly configure
    the `admin.serverPort` in tests to avoid port conflicts. The Zookeeper
    alpha version is not yet officially supported.
  * Integrate eventlet *handler* support into kazoo so that along with [gevent,
    threading] handlers there can now be a dedicated eventlet handler for
    projects that need to (or want to) use eventlet (such as those working
    in the openstack community). The ``requirements_eventlet.txt`` file lists
    the optional eventlet requirement(s) that needs to be satisfied when this
    new handler is used.
  * Use ``six`` to nicely handle the cross compatibility of kazoo with
    python 2.x and 3.x (reducing/removing the need to have custom compatibility
    code that replicates what six already provides).
  * Add ``state_change_event`` to ``kazoo.recipe.partitioner.SetPartitioner``
    which is set on every state change.
  * Add a NonBlockingLease recipe.  The recipe allows e.g. cron jobs scheduled
    on multiple machines to ensure that at most N instances will run a particular
    job, with lease timeout for graceful handover in case of node failures.
* Mon Sep 15 2014 tbechtold@suse.com
- update to version 2.0
  * Extend support to Python 3.4, deprecating Python 3.2.
  * Issue #198: Mention Zake as a sophisticated kazoo mock testing library.
  * Issue #181: Add documentation on basic logging setup.
  * Null or None data is no longer treated as "". Pull req #165, patch by
    Raul Gutierrez S. This will affect how you should treat null data in a
    znode vs. an empty string.
  * Passing acl=[] to create() now works properly instead of an InvalidACLError
    as it returned before. Patch by Raul Gutierrez S in PR #164.
  * Removed the dependency on zope.interface. The classes in the interfaces
    module are left for documentation purposes only (issue #131).
  * Logging levels have been reduced.
    + Logging previously at the ``logging.DEBUG`` level is now logged at
    the ``kazoo.loggingsupport.BLATHER`` level (5).
    + Some low-level logging previously at the ``logging.INFO`` level is
    now logged at the ``logging.DEBUG`` level.
  * Issue #133: Introduce a new environment variable `ZOOKEEPER_PORT_OFFSET`
    for the testing support, to run the testing cluster on a different range.
  * When authenticating via add_auth() the auth data will be saved to ensure that
    the authentication happens on reconnect (as is the case when feeding auth
    data via KazooClient's constructor). PR #172, patch by Raul Gutierrez S.
  * Change gevent import to remove deprecation warning when newer gevent is
    used. PR #191, patch by Hiroaki Kawai.
  * Lock recipe was failing to use the client's sleep_func causing issues with
    gevent. Issue #150.
  * Calling a DataWatch or ChildrenWatch instance twice (decorator) now throws
    an exception as only a single function can be associated with a single
    watcher. Issue #154.
  * Another fix for atexit handling so that when disposing of connections the
    atexit handler is removed. PR #190, patch by Devaev Maxim.
  * Fix atexit handling for kazoo threading handler, PR #183. Patch by
    Brian Wickman.
  * Partitioner should handle a suspended connection properly and restore
    an allocated state if it was allocated previously. Patch by Manish Tomar.
  * Issue #167: Closing a client that was never started throws a type error.
    Patch by Joshua Harlow.
  * Passing dictionaries to KazooClient.__init__() wasn't actually working
    properly. Patch by Ryan Uber.
  * Issue #119: Handler timeout takes the max of the random interval or
    the read timeout to ensure a negative number isn't used for the read
    timeout.
  * Fix ordering of exception catches in lock.acquire as it was capturing a
    parent exception before the child. Patch by ReneSac.
  * Fix issue with client.stop() not always setting the client state to
    KeeperState.CLOSED. Patch by Jyrki Pulliainen in PR #174.
  * Issue #169: Fixed pipes leaking into child processes.
  * Add section on contributing recipes, add maintainer/status information for
    existing recipes.
  * Add note about alternate use of DataWatch.
- Remove Require python-zope.interfaces
* Wed Apr  2 2014 speilicke@suse.com
- Initial version
